/*
 * Copyright (c) 2007 Uwe Schmidt
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * 
 * Created on 27.05.2005
 */

package controller;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URL;

import javax.swing.JFrame;
import javax.swing.JOptionPane;

public class CommInstaller {

	private Model model;

	public CommInstaller(Model model) {
		this.model = model;
	}

	public void installCommApi(JFrame frame) {

		String sep = System.getProperty("file.separator");
		String jhome = System.getProperty("java.home");
		String libfolder = System.getProperty("java.library.path");
		String jlibpath = null;

		String[] folder = libfolder.split(";");
		for (int i = 0; i < folder.length; i++) {
			if (folder[i].indexOf(jhome) != -1) {
				jlibpath = folder[i];
			}
		}

		// Lib folder inside java.home wasn't found => ask for folder to install
		if (jlibpath == null) {

			jlibpath = (String) JOptionPane.showInputDialog(frame, "", "Select Library-Folder to install", JOptionPane.PLAIN_MESSAGE, null, folder, "");

			// User chose "Ok"
			if ((jlibpath != null) && (jlibpath.length() > 0)) {
			} else {
				// User chose "Cancel" ...
				jlibpath = null;
				model.log("Installation aborted.");
				return;
			}
		}

		// ready to install

		// folder to copy javax.comm.properties to
		String propfolder = jhome + sep + "lib";

		// System.out.println(jhome);
		// System.out.println(jlibpath);
		// System.out.println(propfolder);

		URL serialdll = getClass().getResource("lib/rxtxSerial.dll");
		URL paralleldll = getClass().getResource("lib/rxtxParallel.dll");
		URL propfile = getClass().getResource("lib/javax.comm.properties");

		try {
			model.log("Copying rxtxSerial.dll to " + jlibpath);
			copyFile(serialdll.openStream(), new File(jlibpath + sep + "rxtxSerial.dll"), 1024);
			model.log("Copying rxtxParallel.dll to " + jlibpath);
			copyFile(paralleldll.openStream(), new File(jlibpath + sep + "rxtxParallel.dll"), 1024);
			model.log("Copying javax.comm.properties to " + propfolder);
			copyFile(propfile.openStream(), new File(propfolder + sep + "javax.comm.properties"), 1024);
		} catch (IOException e) {
			model.log(e.getMessage());
		}

		model.log("Comm-API has been successfully installed.");
	}

	public void copyFile(File src, File dest, int bufSize) throws IOException {
		InputStream in = null;
		try {
			in = new FileInputStream(src);
			copyFile(in, dest, bufSize);
		} finally {
			if (in != null)
				in.close();
		}
	}

	public void copyFile(InputStream in, File dest, int bufSize) throws IOException {

		byte[] buffer = new byte[bufSize];
		int read = 0;

		OutputStream out = null;
		try {
			out = new FileOutputStream(dest);
			while (true) {
				read = in.read(buffer);
				if (read == -1) {
					break;
				}
				out.write(buffer, 0, read);
			}
		} finally {
			if (in != null) {
				try {
					in.close();
				} finally {
					if (out != null) {
						out.close();
					}
				}
			}
		}
	}

}
