/*
 * Copyright (c) 2007 Uwe Schmidt
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 * 
 * Created on 18.05.2005
 */

package controller.gui;

import java.awt.Color;
import java.awt.FlowLayout;
import java.util.Observable;
import java.util.Observer;

import javax.swing.BorderFactory;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.border.EtchedBorder;

import controller.Model;
import controller.SerialConnection;

@SuppressWarnings("serial")
public class StatusBar extends JPanel implements Observer {

	private Model model;
	private SerialConnection connection;
	private JLabel connStatus, comPort, toolTip;

	public StatusBar(Model model) {
		this.model = model;
		model.addObserver(this);
		connection = model.getConnection();
		connection.addObserver(this);

		// setBorder(BorderFactory.createLoweredBevelBorder());

		// pass aligment, hgap, vgap
		FlowLayout layout = new FlowLayout(FlowLayout.LEFT, 1, 0);
		setLayout(layout);

		// create & add Status Label
		add(comPort = createLabel());
		add(connStatus = createLabel());

		toolTip = new JLabel();
		toolTip.setForeground(Color.GRAY);
		add(toolTip);

		// set Text on Labels
		getInfos();
	}

	// get Status information
	private void getInfos() {
		comPort.setText(model.getProperty("COM"));
		connStatus.setText(connection.isOnline() ? SerialConnection.ONLINE : SerialConnection.OFFLINE);
	}

	private JLabel createLabel() {
		JLabel label = new JLabel();
		label.setBorder(BorderFactory.createEtchedBorder(EtchedBorder.LOWERED));
		return label;
	}

	public void setToolTip(String tt) {
		toolTip.setText(" " + tt);
	}

	public void update(Observable observable, Object msg) {

		// message from serialconnection is either "Online" or "Offline"
		if (observable == connection) {
			connStatus.setText((String) msg);
			return;
		}

		if (msg == Model.PROPERTIES_CHANGE) {
			// check if COM-Port has changed
			getInfos();
		}

	}
}
